@@ -36,8 +36,8 @@ sub new {
     $self->{'offset'} = App::GUI::Harmonograph::SliderCombo->new
                             ($self, 110, 'Offset', 'additional offset pendulum starts with (0 - quater rotation)', 0, 100, 0);
                             
-    $self->{'radius'} = App::GUI::Harmonograph::SliderCombo->new( $self, 100, 'r', 'radius of pendulum swing', 0, 150, 100);
-    $self->{'damp'} = App::GUI::Harmonograph::SliderCombo->new( $self, 100, 'Damp', 'damping factor', 0, 1000, 0);
+    $self->{'radius'} = App::GUI::Harmonograph::SliderCombo->new( $self, 100, 'r', 'radius or amplitude of pendulum swing', 0, 150, 100);
+    $self->{'damp'} = App::GUI::Harmonograph::SliderCombo->new( $self, 100, 'Damp', 'damping factor (diminishes amplitude over time)', 0, 1000, 0);
 
 
     Wx::Event::EVT_CHECKBOX( $self, $self->{'on'},          sub { $self->update_enable(); $self->{'callback'}->() });
@@ -115,15 +115,15 @@ sub set_data {
     $data->{ 'frequency'} = abs $data->{'frequency'};
     $self->{ 'invert_freq' }->SetValue( $data->{'frequency'} < 1 );
     $data->{ 'frequency'} = 1 / $data->{'frequency'} if $data->{'frequency'} < 1;
-    $self->{ 'frequency' }->SetValue( int $data->{'frequency'} );
-    $self->{ 'freq_dez' }->SetValue( int( 1000 * ($data->{'frequency'} - int $data->{'frequency'} ) ) );
+    $self->{ 'frequency' }->SetValue( int $data->{'frequency'}, 1 );
+    $self->{ 'freq_dez' }->SetValue( int( 1000 * ($data->{'frequency'} - int $data->{'frequency'} ) ), 1 );
     $self->{ 'half_off' }->SetValue( $data->{'offset'} >= 0.5 );
     $data->{ 'offset' } -= 0.5 if $data->{'offset'} >= 0.5;
     $self->{ 'quarter_off' }->SetValue( $data->{'offset'} >= 0.25 );
     $data->{ 'offset' } -= 0.25 if $data->{'offset'} >= 0.25;
-    $self->{'offset'}->SetValue( int( $data->{'offset'} * 400 ));
-    $self->{ 'radius' }->SetValue( $data->{'radius'} * 100 );
-    $self->{ 'damp' }->SetValue( $data->{'damp'} );
+    $self->{'offset'}->SetValue( int( $data->{'offset'} * 400 ), 1);
+    $self->{ 'radius' }->SetValue( $data->{'radius'} * 100, 1 );
+    $self->{ 'damp' }->SetValue( $data->{'damp'}, 1 );
     $self->update_enable;
     1;
 }
